@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals, division
-
-VERSION = (1, 0, 11)
+VERSION = (1, 0, 12)
 __version__ = ".".join(map(str, VERSION))
 
 default_app_config = "binary_database_files.apps.DatabaseFilesAppConfig"
